@@ -1,5 +1,5 @@
 //
-// Copyright (C) 2010-2020 Codership Oy <info@codership.com>
+// Copyright (C) 2010-2021 Codership Oy <info@codership.com>
 //
 
 #include "galera_common.hpp"
@@ -166,6 +166,7 @@ galera::ReplicatorSMM::ReplicatorSMM(const struct wsrep_init_args* args)
     sst_cond_           (),
 #endif /* HAVE_PSI_INTERFACE */
     sst_retry_sec_      (1),
+    last_st_type_       (ST_TYPE_NONE),
     gcache_             (config_, config_.get(BASE_DIR)),
     gcs_                (config_, gcache_, proto_max_, args->proto_ver,
                          args->node_name, args->node_incoming),
@@ -1536,6 +1537,22 @@ app_wants_state_transfer (const void* const req, ssize_t const req_len)
             memcmp(req, WSREP_STATE_TRANSFER_NONE, req_len));
 }
 
+int
+wsrep_uuid_print (const wsrep_uuid_t* uuid, char* str, size_t str_len)
+{
+    if (str_len > 36) {
+        const unsigned char* u = uuid->data;
+        return snprintf(str, str_len, "%02x%02x%02x%02x-%02x%02x-%02x%02x-"
+                        "%02x%02x-%02x%02x%02x%02x%02x%02x",
+                        u[ 0], u[ 1], u[ 2], u[ 3], u[ 4], u[ 5], u[ 6], u[ 7],
+                        u[ 8], u[ 9], u[10], u[11], u[12], u[13], u[14], u[15]);
+    }
+    else {
+        return -EMSGSIZE;
+    }
+}
+
+
 void
 galera::ReplicatorSMM::update_incoming_list(const wsrep_view_info_t& view)
 {
@@ -1567,6 +1584,16 @@ galera::ReplicatorSMM::update_incoming_list(const wsrep_view_info_t& view)
         incoming_list_ += separator;
         incoming_list_ += view.members[i].incoming;
     }
+
+    std::vector<std::string> allowed_IST_clients;
+    for (int i = 0; i < view.memb_num; ++i)
+    {
+       char tmp[GU_UUID_STR_LEN+1];
+       wsrep_uuid_print(&(view.members[i].id), tmp, GU_UUID_STR_LEN+1);
+       allowed_IST_clients.push_back(tmp);
+    }
+    ist_senders_.terminate(allowed_IST_clients);
+
 }
 
 void
@@ -1978,9 +2005,31 @@ wsrep_status_t galera::ReplicatorSMM::cert(TrxHandle* trx)
     if (!applicable)
     {
         // this can happen after state transfer position has been submitted
-        // but not all actions preceding it have been processed
+        // but not all actions preceding it have been processed.
+        //
+        // Cert index preload after SST:
+        // ----------------------------
+        // If the trx global seqno is in the half open range
+        // (cc_seqno_ , sst_seqno_], the write set was contained in the SST.
+        // In this case do the certification for trx to populate the index,
+        // but ignore the result. Always set state as S_MUST_ABORT and
+        // return WSREP_TRX_FAIL to make calling code to discard this trx.
+        if (last_st_type_ == ST_TYPE_SST &&
+            cc_seqno_ < trx->global_seqno() &&
+            trx->global_seqno() <= sst_seqno_)
+        {
+            (void)cert_.append_trx(trx);
+            trx->verify_checksum();
+            gcache_.seqno_assign (trx->action(),
+                                  trx->global_seqno(),
+                                  trx->depends_seqno());
+            cert_.set_trx_committed(trx);
+        }
+        else
+        {
+            gcache_.free(const_cast<void*>(trx->action()));
+        }
         trx->set_state(TrxHandle::S_MUST_ABORT);
-        gcache_.free(const_cast<void*>(trx->action()));
         if (interrupted)
             local_monitor_.self_cancel(lo);
         else
