@@ -868,24 +868,12 @@ wsrep_status_t galera_free_connection(wsrep_t*        const gh,
 {
     assert(gh != 0);
     assert(gh->ctx != 0);
-
-    REPL_CLASS * repl(reinterpret_cast< REPL_CLASS * >(gh->ctx));
-
-    try
-    {
-        repl->discard_local_conn(conn_id);
-        return WSREP_OK;
-    }
-    catch (std::exception& e)
-    {
-        log_warn << e.what();
-        return WSREP_CONN_FAIL;
-    }
-    catch (...)
-    {
-        log_fatal << "non-standard exception";
-        return WSREP_FATAL;
-    }
+    // This function is now no-op and can be removed from the
+    // future versions. Connection object is allocated only from
+    // galera_to_execute_start() and will be released either
+    // from that function in case of failure or from
+    // galera_to_execute_end().
+    return WSREP_OK;
 }
 
 
@@ -969,29 +957,35 @@ wsrep_status_t galera_to_execute_end(wsrep_t*        const gh,
 
     REPL_CLASS * repl(reinterpret_cast< REPL_CLASS * >(gh->ctx));
 
-    wsrep_status_t retval;
     TrxHandle* trx(repl->local_conn_trx(conn_id, false));
 
+    if (trx == 0)
+    {
+        log_warn << "Could not find local connection object for "
+                 << conn_id;
+        return WSREP_WARNING;
+    }
+
+    wsrep_status_t ret(WSREP_OK);
     try
     {
         TrxHandleLock lock(*trx);
         repl->to_isolation_end(trx);
-        repl->discard_local_conn_trx(conn_id);
-        return WSREP_OK;
-        // trx will be unreferenced (destructed) during purge
     }
     catch (std::exception& e)
     {
         log_warn << e.what();
-        return WSREP_CONN_FAIL;
+        ret = WSREP_CONN_FAIL;
     }
     catch (...)
     {
         log_fatal << "non-standard exception";
-        return WSREP_FATAL;
+        ret = WSREP_FATAL;
     }
 
-    return retval;
+    // trx will be unreferenced (destructed) during purge
+    repl->discard_local_conn_trx(conn_id);
+    return ret;
 }
 
 
@@ -1142,6 +1136,16 @@ void galera_stats_reset (wsrep_t* gh)
     repl->stats_reset();
 }
 
+extern "C"
+void galera_fetch_pfs_info (wsrep_t* gh, wsrep_node_info_t* nodes, uint32_t size)
+{
+    assert(gh != 0);
+    assert(gh->ctx != 0);
+
+    REPL_CLASS* repl(reinterpret_cast< REPL_CLASS * >(gh->ctx));
+
+    repl->fetch_pfs_info(nodes, size);
+}
 
 extern "C"
 wsrep_seqno_t galera_pause (wsrep_t* gh)
@@ -1296,6 +1300,7 @@ static wsrep_t galera_str = {
     &galera_stats_get,
     &galera_stats_free,
     &galera_stats_reset,
+    &galera_fetch_pfs_info,
     &galera_pause,
     &galera_resume,
     &galera_desync,
