@@ -364,3 +364,8 @@ function get_absolute_path()
     printf "%s/%s" "${abs_path}" "${filename}"
     return 0
 }
+
+# timeout for donor to connect to joiner (seconds)
+readonly WSREP_SST_DONOR_TIMEOUT=$(parse_cnf sst donor-timeout 10)
+# For backward compatiblitiy: joiner timeout waiting for donor connection
+readonly WSREP_SST_JOINER_TIMEOUT=$(parse_cnf sst joiner-timeout $(parse_cnf sst sst-initial-timeout 60) )
