@@ -1,6 +1,6 @@
 #ifndef MDL_H
 #define MDL_H
-/* Copyright (c) 2009, 2016, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2009, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -399,7 +399,7 @@ public:
       are not longer than NAME_LEN. Still we play safe and try to avoid
       buffer overruns.
     */
-    DBUG_ASSERT(strlen(db) <= NAME_LEN && strlen(name) <= NAME_LEN);
+    assert(strlen(db) <= NAME_LEN && strlen(name) <= NAME_LEN);
     m_db_name_length= static_cast<uint16>(strmake(m_ptr + 1, db, NAME_LEN) -
                                           m_ptr - 1);
     m_length= static_cast<uint16>(strmake(m_ptr + m_db_name_length + 2, name,
@@ -521,7 +521,7 @@ public:
   /** Set type of lock request. Can be only applied to pending locks. */
   inline void set_type(enum_mdl_type type_arg)
   {
-    DBUG_ASSERT(ticket == NULL);
+    assert(ticket == NULL);
     type= type_arg;
   }
 
@@ -738,12 +738,12 @@ private:
   friend class MDL_context;
 
   MDL_ticket(MDL_context *ctx_arg, enum_mdl_type type_arg
-#ifndef DBUG_OFF
+#ifndef NDEBUG
              , enum_mdl_duration duration_arg
 #endif
             )
    : m_type(type_arg),
-#ifndef DBUG_OFF
+#ifndef NDEBUG
      m_duration(duration_arg),
 #endif
      m_ctx(ctx_arg),
@@ -755,11 +755,11 @@ private:
 
   virtual ~MDL_ticket()
   {
-    DBUG_ASSERT(m_psi == NULL);
+    assert(m_psi == NULL);
   }
 
   static MDL_ticket *create(MDL_context *ctx_arg, enum_mdl_type type_arg
-#ifndef DBUG_OFF
+#ifndef NDEBUG
                             , enum_mdl_duration duration_arg
 #endif
                             );
@@ -767,7 +767,7 @@ private:
 private:
   /** Type of metadata lock. Externally accessible. */
   enum enum_mdl_type m_type;
-#ifndef DBUG_OFF
+#ifndef NDEBUG
   /**
     Duration of lock represented by this ticket.
     Context private. Debug-only.
@@ -1232,7 +1232,7 @@ void mdl_init();
 void mdl_destroy();
 
 
-#ifndef DBUG_OFF
+#ifndef NDEBUG
 extern mysql_mutex_t LOCK_open;
 #endif
 
