@@ -93,6 +93,7 @@ bool set_gtid_next(THD *thd, const Gtid_specification &spec)
     assert(spec.type == GTID_GROUP);
     assert(spec.gtid.sidno >= 1);
     assert(spec.gtid.gno >= 1);
+    assert(spec.gtid.gno < GNO_END);
     while (true)
     {
       // loop invariant: we should always hold global_sid_lock.rdlock
@@ -128,6 +129,7 @@ bool set_gtid_next(THD *thd, const Gtid_specification &spec)
         thd->variables.gtid_next= spec;
         assert(thd->owned_gtid.sidno >= 1);
         assert(thd->owned_gtid.gno >= 1);
+        assert(thd->owned_gtid.gno < GNO_END);
         break;
       }
       // GTID owned by someone (other thread)
