@@ -1,4 +1,4 @@
-/* Copyright (c) 2015, 2017, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2015, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -265,7 +265,7 @@ private:
     while (*p->ptr)
     {
       p->ptr++;
-      DBUG_ASSERT(p->ptr < p->end);               // because p->free > 0
+      assert(p->ptr < p->end);               // because p->free > 0
     }
 
     /* found! store xid there and mark the page dirty */
