@@ -1,6 +1,6 @@
 /*****************************************************************************
 
-Copyright (c) 2007, 2018, Oracle and/or its affiliates. All Rights Reserved.
+Copyright (c) 2007, 2021, Oracle and/or its affiliates.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License, version 2.0,
@@ -565,6 +565,9 @@ fts_ast_node_check_union(
 			}
 		}
 
+	} else if (node->type == FTS_AST_PARSER_PHRASE_LIST) {
+		/* Phrase search for plugin parser */
+		return(false);
 	} else if (node->type == FTS_AST_OPER
 		   && (node->oper == FTS_IGNORE
 		       || node->oper == FTS_EXIST)) {
