@@ -575,6 +575,18 @@ int thd_slave_thread(const MYSQL_THD thd);
 @retval 1 the user thread is running a non-transactional update */
 int thd_non_transactional_update(const MYSQL_THD thd);
 
+/** Check if the thread has attachable transaction
+@param thd user thread
+@retval 0 thd doesn't have attachable trx
+@retval 1 thd has attachable trx */
+int thd_has_active_attachable_trx(const MYSQL_THD thd);
+
+/** Check if the thread is doing a gtid operation implicitly
+@param thd user thread
+@retval 0 thd is not doing any gtid implicit operation
+@retval 1 thd is doing gtid implicit operation */
+int thd_is_operating_gtid_table_implicitly(const MYSQL_THD thd);
+
 /** Get the user thread's binary logging format
 @param thd user thread
 @return Value to be used as index into the binlog_format_names array */
@@ -662,6 +674,12 @@ typedef struct new_ft_info
 	fts_result_t*		ft_result;
 } NEW_FT_INFO;
 
+/* Check if the thread can skip  innodb concurrency check
+@param[in]	row_prebuilt_t*	 prebuilt
+@return true if thread can skip innodb concurrency check*/
+ibool
+skip_concurrency_ticket(row_prebuilt_t* prebuilt);
+
 /**
 Allocates an InnoDB transaction for a MySQL handler object.
 @return InnoDB transaction handle */
