@@ -664,7 +664,7 @@ struct trx_sys_t {
 					transactions), protected by
 					rseg->mutex */
 
-	trx_rseg_t*	const pending_purge_rseg_array[TRX_SYS_N_RSEGS];
+	trx_rseg_t*	pending_purge_rseg_array[TRX_SYS_N_RSEGS];
 					/*!< Pointer array to rollback segments
 					between slot-1..slot-srv_tmp_undo_logs
 					that are now replaced by non-redo
