@@ -1380,15 +1380,14 @@ trx_sys_close(void)
 		}
 	}
 
-	rseg_array = ((trx_rseg_t**) trx_sys->pending_purge_rseg_array);
-
 	for (ulint i = 0; i < TRX_SYS_N_RSEGS; ++i) {
 		trx_rseg_t*	rseg;
 
 		rseg = trx_sys->pending_purge_rseg_array[i];
 
 		if (rseg != NULL) {
-			trx_rseg_mem_free(rseg, rseg_array);
+			trx_rseg_mem_free(rseg,
+				trx_sys->pending_purge_rseg_array);
 		}
 	}
 
