@@ -1,4 +1,4 @@
-/* Copyright (c) 2008, 2019, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2008, 2021, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
@@ -151,13 +151,13 @@ bool PFS_table_context::initialize(void)
   {
     /* Restore context from TLS. */
     PFS_table_context *context= static_cast<PFS_table_context *>(my_get_thread_local(m_thr_key));
-    DBUG_ASSERT(context != NULL);
+    assert(context != NULL);
 
     if(context)
     {
       m_last_version= context->m_current_version;
       m_map= context->m_map;
-      DBUG_ASSERT(m_map_size == context->m_map_size);
+      assert(m_map_size == context->m_map_size);
       m_map_size= context->m_map_size;
       m_word_size= context->m_word_size;
     }
@@ -166,7 +166,7 @@ bool PFS_table_context::initialize(void)
   {
     /* Check that TLS is not in use. */
     PFS_table_context *context= static_cast<PFS_table_context *>(my_get_thread_local(m_thr_key));
-    //DBUG_ASSERT(context == NULL);
+    //assert(context == NULL);
 
     context= this;
 
@@ -662,28 +662,28 @@ void PFS_engine_table::get_normalizer(PFS_instr_class *instr_class)
 
 void PFS_engine_table::set_field_long(Field *f, long value)
 {
-  DBUG_ASSERT(f->real_type() == MYSQL_TYPE_LONG);
+  assert(f->real_type() == MYSQL_TYPE_LONG);
   Field_long *f2= (Field_long*) f;
   f2->store(value, false);
 }
 
 void PFS_engine_table::set_field_ulong(Field *f, ulong value)
 {
-  DBUG_ASSERT(f->real_type() == MYSQL_TYPE_LONG);
+  assert(f->real_type() == MYSQL_TYPE_LONG);
   Field_long *f2= (Field_long*) f;
   f2->store(value, true);
 }
 
 void PFS_engine_table::set_field_longlong(Field *f, longlong value)
 {
-  DBUG_ASSERT(f->real_type() == MYSQL_TYPE_LONGLONG);
+  assert(f->real_type() == MYSQL_TYPE_LONGLONG);
   Field_longlong *f2= (Field_longlong*) f;
   f2->store(value, false);
 }
 
 void PFS_engine_table::set_field_ulonglong(Field *f, ulonglong value)
 {
-  DBUG_ASSERT(f->real_type() == MYSQL_TYPE_LONGLONG);
+  assert(f->real_type() == MYSQL_TYPE_LONGLONG);
   Field_longlong *f2= (Field_longlong*) f;
   f2->store(value, true);
 }
@@ -691,7 +691,7 @@ void PFS_engine_table::set_field_ulonglong(Field *f, ulonglong value)
 void PFS_engine_table::set_field_char_utf8(Field *f, const char* str,
                                            uint len)
 {
-  DBUG_ASSERT(f->real_type() == MYSQL_TYPE_STRING);
+  assert(f->real_type() == MYSQL_TYPE_STRING);
   Field_string *f2= (Field_string*) f;
   f2->store(str, len, &my_charset_utf8_bin);
 }
@@ -701,7 +701,7 @@ void PFS_engine_table::set_field_varchar(Field *f,
                                          const char* str,
                                          uint len)
 {
-  DBUG_ASSERT(f->real_type() == MYSQL_TYPE_VARCHAR);
+  assert(f->real_type() == MYSQL_TYPE_VARCHAR);
   Field_varstring *f2= (Field_varstring*) f;
   f2->store(str, len, cs);
 }
@@ -709,7 +709,7 @@ void PFS_engine_table::set_field_varchar(Field *f,
 void PFS_engine_table::set_field_varchar_utf8(Field *f, const char* str,
                                               uint len)
 {
-  DBUG_ASSERT(f->real_type() == MYSQL_TYPE_VARCHAR);
+  assert(f->real_type() == MYSQL_TYPE_VARCHAR);
   Field_varstring *f2= (Field_varstring*) f;
   f2->store(str, len, &my_charset_utf8_bin);
 }
@@ -717,7 +717,7 @@ void PFS_engine_table::set_field_varchar_utf8(Field *f, const char* str,
 void PFS_engine_table::set_field_longtext_utf8(Field *f, const char* str,
                                                uint len)
 {
-  DBUG_ASSERT(f->real_type() == MYSQL_TYPE_BLOB);
+  assert(f->real_type() == MYSQL_TYPE_BLOB);
   Field_blob *f2= (Field_blob*) f;
   f2->store(str, len, &my_charset_utf8_bin);
 }
@@ -725,14 +725,14 @@ void PFS_engine_table::set_field_longtext_utf8(Field *f, const char* str,
 void PFS_engine_table::set_field_blob(Field *f, const char* val,
                                       uint len)
 {
-  DBUG_ASSERT(f->real_type() == MYSQL_TYPE_BLOB);
+  assert(f->real_type() == MYSQL_TYPE_BLOB);
   Field_blob *f2= (Field_blob*) f;
   f2->store(val, len, &my_charset_utf8_bin);
 }
 
 void PFS_engine_table::set_field_enum(Field *f, ulonglong value)
 {
-  DBUG_ASSERT(f->real_type() == MYSQL_TYPE_ENUM);
+  assert(f->real_type() == MYSQL_TYPE_ENUM);
   Field_enum *f2= (Field_enum*) f;
   f2->store_type(value);
 }
@@ -742,21 +742,21 @@ void PFS_engine_table::set_field_timestamp(Field *f, ulonglong value)
   struct timeval tm;
   tm.tv_sec= (long)(value / 1000000);
   tm.tv_usec= (long)(value % 1000000);
-  DBUG_ASSERT(f->real_type() == MYSQL_TYPE_TIMESTAMP2);
+  assert(f->real_type() == MYSQL_TYPE_TIMESTAMP2);
   Field_timestampf *f2= (Field_timestampf*) f;
   f2->store_timestamp(& tm);
 }
 
 void PFS_engine_table::set_field_double(Field *f, double value)
 {
-  DBUG_ASSERT(f->real_type() == MYSQL_TYPE_DOUBLE);
+  assert(f->real_type() == MYSQL_TYPE_DOUBLE);
   Field_double *f2= (Field_double*) f;
   f2->store(value);
 }
 
 ulonglong PFS_engine_table::get_field_enum(Field *f)
 {
-  DBUG_ASSERT(f->real_type() == MYSQL_TYPE_ENUM);
+  assert(f->real_type() == MYSQL_TYPE_ENUM);
   Field_enum *f2= (Field_enum*) f;
   return f2->val_int();
 }
@@ -764,7 +764,7 @@ ulonglong PFS_engine_table::get_field_enum(Field *f)
 String*
 PFS_engine_table::get_field_char_utf8(Field *f, String *val)
 {
-  DBUG_ASSERT(f->real_type() == MYSQL_TYPE_STRING);
+  assert(f->real_type() == MYSQL_TYPE_STRING);
   Field_string *f2= (Field_string*) f;
   val= f2->val_str(NULL, val);
   return val;
@@ -773,7 +773,7 @@ PFS_engine_table::get_field_char_utf8(Field *f, String *val)
 String*
 PFS_engine_table::get_field_varchar_utf8(Field *f, String *val)
 {
-  DBUG_ASSERT(f->real_type() == MYSQL_TYPE_VARCHAR);
+  assert(f->real_type() == MYSQL_TYPE_VARCHAR);
   Field_varstring *f2= (Field_varstring*) f;
   val= f2->val_str(NULL, val);
   return val;
@@ -869,7 +869,7 @@ static bool allow_drop_table_privilege() {
     return false;
   }
 
-  DBUG_ASSERT(thd->lex != NULL);
+  assert(thd->lex != NULL);
   if ((thd->lex->sql_command != SQLCOM_TRUNCATE) &&
       (thd->lex->sql_command != SQLCOM_GRANT)) {
     return false;
